=======
History
=======

0.4.0-alpha (2022-06-24)
------------------------

* First release on PyPI.

0.4.1 (2022-06-27)
-------------------

* Fixed novelty formula.

0.5.0 (2022-07-19)
-------------------

* Added a new item segmentation method, which gives a percentage score to the items based on their popularity.
* More accurate docs, with a beautiful theme.

0.5.1 (2022-07-27)
-------------------

* Fixed mantissa problem with the sum of proportion in the segmentation part.
* Improved code readability and tests coverage.
